@@ -4,7 +4,7 @@ test_that("matches arg", {
   myarg <- c("foo", "baz")
   expect_identical(arg_match(myarg, c("bar", "foo")), "foo")
   expect_error(
-    regex = "`myarg` should be one of: \"bar\" or \"baz\"",
+    regex = "`myarg` must be one of \"bar\" or \"baz\"",
     arg_match(myarg, c("bar", "baz"))
   )
 })
@@ -35,3 +35,9 @@ test_that("is_missing() works with non-symbols", {
   expect_true(is_missing(l[[1]]))
   expect_error(missing(l[[1]]), "invalid use")
 })
+
+test_that("maybe_missing() forwards missing value", {
+  x <- missing_arg()
+  expect_true(is_missing(maybe_missing(x)))
+  expect_false(is_missing(maybe_missing(1L)))
+})
